NAME = "bluer_sandbox"

ICON = "🌀"

DESCRIPTION = f"{ICON} A sandbox for ideas and experiments."

VERSION = "5.516.1"

REPO_NAME = "bluer-sandbox"

MARQUEE = "https://github.com/kamangir/assets/raw/main/blue-plugin/marquee.png?raw=true"

ALIAS = "@sandbox"


def fullname() -> str:
    return f"{NAME}-{VERSION}"
